@@ -1,15 +1,17 @@
 This is an R port of survival5
 
-It requires version 0.64.1 or later of R.
+It requires version 0.65.1 or later of R. The previous version 1.0-0 works
+with R 0.64.1 or later. Version 1.1 is a bug fix to compile under
+Linux/glibc 2.1
 
-You will need the splines library and you will probably want the date
-library.
+You will probably want to install the date library. If your R predates 0.90
+you will also need the splines library.
 
-The main new feature is penalised (partial) likelihood. Both survreg() and
-coxph() can now fit frailty models, smoothing splines, ridge regressions
-and other penalised estimation methods.  This is also the largest change
-in porting, since the S-PLUS implementation uses S frames directly. The R
-implementation uses functions and environments.
+The main new feature since survival4 is penalised (partial) likelihood.
+Both survreg() and coxph() can now fit frailty models, smoothing splines,
+ridge regressions and other penalised estimation methods.  This is also
+the largest change in porting, since the S-PLUS implementation uses S
+frames directly. The R implementation uses functions and environments.
 
 The parametric survival models are more numerically stable. They will now
 fit some nasty examples where the the loglikelihood is nowhere near
